==> pegasus-merchandise-api-2.1.5-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpMainProdCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.util.Date;

/**
 * Created by gensheng.ye on 2018/12/21.
 */
public class OpMainProdCond extends BaseQueryCond {
    private Integer id;
    private Integer productId;
    private String productCode;
    private Integer detailBigimgSeq;
    private String status;
    private String createUsername;
    private String createNickname;
    private Date createTimeStart;
    private Date createTimeEnd;



    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProductId() {
        return productId;
    }

    public void setProductId(Integer productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }


    public Integer getDetailBigimgSeq() {
        return detailBigimgSeq;
    }

    public void setDetailBigimgSeq(Integer detailBigimgSeq) {
        this.detailBigimgSeq = detailBigimgSeq;
    }


    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCreateUsername() {
        return createUsername;
    }

    public void setCreateUsername(String createUsername) {
        this.createUsername = createUsername;
    }

    public String getCreateNickname() {
        return createNickname;
    }

    public void setCreateNickname(String createNickname) {
        this.createNickname = createNickname;
    }

    public Date getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(Date createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public Date getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(Date createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }


}

==> pegasus-merchandise-api-2.3.9-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpMainProdCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2018/12/21.
 */
public class OpMainProdCond extends BaseQueryCond {
    private Integer id;
    private Integer productId;
    private String productCode;
    private Integer detailBigimgSeq;
    private String status;
    private String createUsername;
    private String createNickname;
    private Date createTimeStart;
    private Date createTimeEnd;
    private Long firstFrontCategoryId;
    private List<Long> frontCategoryIds;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProductId() {
        return productId;
    }

    public void setProductId(Integer productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }


    public Integer getDetailBigimgSeq() {
        return detailBigimgSeq;
    }

    public void setDetailBigimgSeq(Integer detailBigimgSeq) {
        this.detailBigimgSeq = detailBigimgSeq;
    }


    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCreateUsername() {
        return createUsername;
    }

    public void setCreateUsername(String createUsername) {
        this.createUsername = createUsername;
    }

    public String getCreateNickname() {
        return createNickname;
    }

    public void setCreateNickname(String createNickname) {
        this.createNickname = createNickname;
    }

    public Date getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(Date createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public Date getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(Date createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }

    public Long getFirstFrontCategoryId() {
        return firstFrontCategoryId;
    }

    public void setFirstFrontCategoryId(Long firstFrontCategoryId) {
        this.firstFrontCategoryId = firstFrontCategoryId;
    }

    public List<Long> getFrontCategoryIds() {
        return frontCategoryIds;
    }

    public void setFrontCategoryIds(List<Long> frontCategoryIds) {
        this.frontCategoryIds = frontCategoryIds;
    }
}
